+++
title = "Markup Front-matter"
markup = "org"
tags = ["front-matter", "markup"]
draft = false
+++

The markup for this post is set to `org`. So the Markdown markup based
emphasis **won't work** here.
